#include "render.h"
#include "screen.h"
#include "window.h"
#include "list.h"
#include <stdio.h>
#include <stdlib.h>
#include <xcb/render.h>

#define PLUGIN_NAME "render"

typedef struct {
    void (*screen_paint)(d_screen_t *sc);
} data_t;

static void render_paint_screen(d_screen_t *sc);
static void paint_root(d_screen_t *sc);
static void paint_window(d_window_t *window);

void
render_init(d_screen_t *sc)
{
    data_t *d = malloc(sizeof(data_t));
    d->screen_paint = sc->screen_paint;
    screen_add_plugin_data(sc, PLUGIN_NAME, d);

    sc->screen_paint = render_paint_screen;
}

void
render_free(d_screen_t *sc)
{
    data_t *d = screen_find_plugin_data(sc, PLUGIN_NAME);
    free(d);
}

static void
render_paint_screen(d_screen_t *sc)
{
    data_t *d = screen_find_plugin_data(sc, PLUGIN_NAME);
    d_list_it_t *it;

    printf("-- painting --\n");
    paint_root(sc);
    for (it = list_bottom(sc->stacking); it; it = it->prev)
        paint_window(it->data);

    /* call the function we replaced in the chain */
    d->screen_paint(sc);
}

static void
paint_root(d_screen_t *sc)
{
    int w, h;

    w = sc->super.width_in_pixels;
    h = sc->super.height_in_pixels;

    //printf("-- paint root 0x%x --\n", sc->super.root);
}

static void
paint_window(d_window_t *w)
{
    //printf("-- paint window 0x%x --\n", w->id);
}
